aboutsummaryrefslogtreecommitdiff
path: root/gcc/config/pdp11/pdp11.h
diff options
context:
space:
mode:
Diffstat (limited to 'gcc/config/pdp11/pdp11.h')
-rw-r--r--gcc/config/pdp11/pdp11.h28
1 files changed, 11 insertions, 17 deletions
diff --git a/gcc/config/pdp11/pdp11.h b/gcc/config/pdp11/pdp11.h
index 55f9993e812..7912beaa151 100644
--- a/gcc/config/pdp11/pdp11.h
+++ b/gcc/config/pdp11/pdp11.h
@@ -89,9 +89,6 @@ extern int target_flags;
/* this is just to play around and check what code gcc generates */ \
{ "branch-expensive", 256}, \
{ "branch-cheap", -256}, \
-/* optimize for space instead of time - just in a couple of places */ \
- { "space", 512 }, \
- { "time", -512 }, \
/* split instruction and data memory? */ \
{ "split", 1024 }, \
{ "no-split", -1024 }, \
@@ -108,7 +105,7 @@ extern int target_flags;
#define TARGET_NO_AC0 (! TARGET_AC0)
#define TARGET_45 (target_flags & 8)
-#define TARGET_40_PLUS ((target_flags & 4) || (target_flags))
+#define TARGET_40_PLUS ((target_flags & 4) || (target_flags & 8))
#define TARGET_10 (! TARGET_40_PLUS)
#define TARGET_BCOPY_BUILTIN (! (target_flags & 16))
@@ -124,9 +121,6 @@ extern int target_flags;
#define TARGET_BRANCH_EXPENSIVE (target_flags & 256)
#define TARGET_BRANCH_CHEAP (!TARGET_BRANCH_EXPENSIVE)
-#define TARGET_SPACE (target_flags & 512)
-#define TARGET_TIME (! TARGET_SPACE)
-
#define TARGET_SPLIT (target_flags & 1024)
#define TARGET_NOSPLIT (! TARGET_SPLIT)
@@ -687,11 +681,11 @@ extern int current_function_pretend_args_size;
/* Addressing modes, and classification of registers for them. */
-#define HAVE_POST_INCREMENT
-/* #define HAVE_POST_DECREMENT */
+#define HAVE_POST_INCREMENT 1
+/* #define HAVE_POST_DECREMENT 0 */
-#define HAVE_PRE_DECREMENT
-/* #define HAVE_PRE_INCREMENT */
+#define HAVE_PRE_DECREMENT 1
+/* #define HAVE_PRE_INCREMENT 0 */
/* Macros to check register numbers against specific register classes. */
@@ -1315,31 +1309,31 @@ JMP FUNCTION 0x0058 0x0000 <- FUNCTION
there is something wrong in MULT because MULT is not
as cheap as total = 2 even if we can shift!
- if TARGET_SPACE make mult etc cheap, but not 1, so when
+ if optimizing for size make mult etc cheap, but not 1, so when
in doubt the faster insn is chosen.
*/
#define RTX_COSTS(X,CODE,OUTER_CODE) \
case MULT: \
- if (TARGET_SPACE) \
+ if (optimize_size) \
total = COSTS_N_INSNS(2); \
else \
total = COSTS_N_INSNS (11); \
break; \
case DIV: \
- if (TARGET_SPACE) \
+ if (optimize_size) \
total = COSTS_N_INSNS(2); \
else \
total = COSTS_N_INSNS (25); \
break; \
case MOD: \
- if (TARGET_SPACE) \
+ if (optimize_size) \
total = COSTS_N_INSNS(2); \
else \
total = COSTS_N_INSNS (26); \
break; \
case ABS: \
/* equivalent to length, so same for TARGET_SPACE */ \
total = COSTS_N_INSNS (3); \
break; \
case ZERO_EXTEND: \
@@ -1358,7 +1352,7 @@ JMP FUNCTION 0x0058 0x0000 <- FUNCTION
case ASHIFT: \
case LSHIFTRT: \
case ASHIFTRT: \
- if (TARGET_SPACE) \
+ if (optimize_size) \
total = COSTS_N_INSNS(1); \
else if (GET_MODE(X) == QImode) \
{ \
@@ -1315,31 +1309,31 @@ JMP FUNCTION 0x0058 0x0000 <- FUNCTION
break; \
case ABS: \
- /* equivalent to length, so same for TARGET_SPACE */ \
+ /* equivalent to length, so same for optimize_size */ \
total = COSTS_N_INSNS (3); \
break; \